pub struct CorpusService;Expand description
Corpus index and cover-selection orchestrator.
Implementations
Sourceimpl CorpusService
impl CorpusService
Sourcepub fn build_index(
index: &dyn CorpusIndex,
corpus_dir: &Path,
) -> Result<usize, AppError>
pub fn build_index( index: &dyn CorpusIndex, corpus_dir: &Path, ) -> Result<usize, AppError>
Sourcepub fn search(
index: &dyn CorpusIndex,
payload: &Payload,
technique: StegoTechnique,
max_results: usize,
) -> Result<Vec<CorpusEntry>, AppError>
pub fn search( index: &dyn CorpusIndex, payload: &Payload, technique: StegoTechnique, max_results: usize, ) -> Result<Vec<CorpusEntry>, AppError>
Search the index for covers that best encode payload using technique.
Errors
Returns AppError::Corpus on failure.
Sourcepub fn search_for_model(
index: &dyn CorpusIndex,
payload: &Payload,
model_id: &str,
resolution: (u32, u32),
max_results: usize,
) -> Result<Vec<CorpusEntry>, AppError>
pub fn search_for_model( index: &dyn CorpusIndex, payload: &Payload, model_id: &str, resolution: (u32, u32), max_results: usize, ) -> Result<Vec<CorpusEntry>, AppError>
Search the index restricted to a specific camera model and resolution.
Errors
Returns AppError::Corpus on failure.
Sourcepub fn model_stats(index: &dyn CorpusIndex) -> Vec<(SpectralKey, usize)>
pub fn model_stats(index: &dyn CorpusIndex) -> Vec<(SpectralKey, usize)>
Return per-model/resolution entry counts from the index.