DistributeService

Struct DistributeService 

pub struct DistributeService;
Distribute a payload across multiple covers.

Implementations

Source

impl DistributeService

pub fn distribute( payload: &Payload, covers: Vec<CoverMedia>, profile: &EmbeddingProfile, distributor: &dyn Distributor, embedder: &dyn EmbedTechnique, ) -> Result<Vec<CoverMedia>, AppError>

Distribute payload across covers.

Errors

Returns AppError::Distribution on failure.

pub fn distribute_with_geographic_manifest( payload: &Payload, covers: Vec<CoverMedia>, manifest: &GeographicManifest, embedder: &dyn EmbedTechnique, distributor: &dyn GeographicDistributor, ) -> Result<Vec<CoverMedia>, AppError>

Distribute payload across covers with a geographic manifest.

Errors

Returns AppError::Opsec on manifest/distribution failures.

pub fn distribute_with_profile_hardening( payload: &Payload, covers: Vec<CoverMedia>, profile: &EmbeddingProfile, distributor: &dyn Distributor, embedder: &dyn EmbedTechnique, deps: &AdaptiveProfileDeps<'_>, ) -> Result<Vec<CoverMedia>, AppError>

Distribute and apply profile-specific adaptive hardening.

For Adaptive, each output cover is optimised against its source cover. For CompressionSurvivable, each output cover is passed through platform recompression simulation.

Errors

Returns AppError::Distribution for distribution failures and AppError::Adaptive for adaptive/profile hardening failures.