pub enum CorpusError {
NoSuitableCover {
payload_bytes: u64,
},
IndexError {
reason: String,
},
AddFailed {
path: String,
reason: String,
},
}Expand description
Errors produced by the corpus steganography bounded context.
Variants
NoSuitableCover
No suitable corpus entry was found for the given payload.
IndexError
The corpus index file is missing or corrupt.
AddFailed
A file could not be added to the corpus index.