CoverProfileMatcher

Trait CoverProfileMatcher 

pub trait CoverProfileMatcher {
    // Required methods
    fn profile_for(&self, cover: &CoverMedia) -> Option<CameraProfile>;
    fn apply_profile(
        &self,
        cover: CoverMedia,
        profile: &CameraProfile,
    ) -> Result<CoverMedia, AdaptiveError>;
}
Camera model fingerprint matching port.

Required Methods

fn profile_for(&self, cover: &CoverMedia) -> Option<CameraProfile>

Return the best-matching CameraProfile for cover, or None if no profile is close enough.

fn apply_profile( &self, cover: CoverMedia, profile: &CameraProfile, ) -> Result<CoverMedia, AdaptiveError>

Apply profile to cover to make it statistically match that camera model.

Errors

Returns AdaptiveError::ProfileMatchFailed.

Implementors