pub struct CanaryServiceImpl { /* private fields */ }Expand description
Adapter implementing canary shard generation and check logic.
Generates an (N+1)th canary shard that cannot participate in real Reed-Solomon reconstruction. The canary is embedded into the first cover that has sufficient capacity.
Implementations